
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef MPC_planner_MSG_LIB_H
#define MPC_planner_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "MPC_plannerType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  MPC_PLANNER_MBOX_NAME                  genomInstanceName("MPC_planner")

#define  MPC_PLANNER_MAX_RQST_SIZE              768

#define  MPC_PLANNER_MBOX_RQST_SIZE       \
 (BUF_SIZE(MPC_PLANNER_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  MPC_PLANNER_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  MPC_PLANNER_MAX_REPLY_SIZE             8

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  MPC_PLANNER_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(MPC_PLANNER_MAX_REPLY_SIZE) \
   + BUF_SIZE(MPC_PLANNER_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define MPC_PLANNER_INIT_RQST 0
#define MPC_PLANNER_SETMODE_RQST 1
#define MPC_PLANNER_PLANTO_RQST 2
#define MPC_PLANNER_PLANSIMPLEPATH_RQST 3
#define MPC_PLANNER_PLANSIMPLESTRAJ_RQST 4
#define MPC_PLANNER_SETMANASYS_RQST 5
#define MPC_PLANNER_STARTPATHRECORDING_RQST 6
#define MPC_PLANNER_STOPPATHRECORDING_RQST 7
#define MPC_PLANNER_LOADPATH_RQST 8
#define MPC_PLANNER_LOADPATHFROMLOC_RQST 9
#define MPC_PLANNER_SAVEPATH_RQST 10
#define MPC_PLANNER_REINITPATH_RQST 11
#define MPC_PLANNER_CONCATPATH_RQST 12
#define MPC_PLANNER_STARTTRAJRECORDING_RQST 13
#define MPC_PLANNER_LOADTRAJ_RQST 14
#define MPC_PLANNER_SAVETRAJ_RQST 15
#define MPC_PLANNER_PLANTRAJPVD_RQST 16
#define MPC_PLANNER_ROTATETRAJ_RQST 17
#define MPC_PLANNER_SHIFTLATTRAJ_RQST 18
#define MPC_PLANNER_SHIFTXYTRAJ_RQST 19
#define MPC_PLANNER_LOADROBUFASTPATH_RQST 20
#define MPC_PLANNER_LOADROBUFASTPATH2_RQST 21
#define MPC_PLANNER_ABORT_RQST 22


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS MPC_plannerClientInit (CLIENT_ID *pClientId);

STATUS MPC_plannerClientEnd (CLIENT_ID clientId);

int MPC_plannerAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int MPC_plannerAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int MPC_plannerAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS MPC_plannerInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PL_INIT_I *(in_Init_I),
					 int replyTimeOut);

extern int MPC_plannerInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PL_INIT_I *(in_Init_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PL_INIT_I *(in_Init_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerSetModeRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 PL_SETMODE_I *(in_SetMode_I),
					 int replyTimeOut);

int MPC_plannerSetModeReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int MPC_plannerSetModeRqstAndRcv (CLIENT_ID clientId, 
				 PL_SETMODE_I *(in_SetMode_I), 
				 
				 int *bilan);




extern STATUS MPC_plannerPlanToRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PL_PLANTO_I *(in_PlanTo_I),
					 int replyTimeOut);

extern int MPC_plannerPlanToReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerPlanToRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PL_PLANTO_I *(in_PlanTo_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerPlanToRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PL_PLANTO_I *(in_PlanTo_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerPlanSimplePathRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PL_PLANSIMPLEPATH_I *(in_PlanSimplePath_I),
					 int replyTimeOut);

extern int MPC_plannerPlanSimplePathReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerPlanSimplePathRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PL_PLANSIMPLEPATH_I *(in_PlanSimplePath_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerPlanSimplePathRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PL_PLANSIMPLEPATH_I *(in_PlanSimplePath_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerPlanSimpleSTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PL_PLANSIMPLESTRAJ_I *(in_PlanSimpleSTraj_I),
					 int replyTimeOut);

extern int MPC_plannerPlanSimpleSTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerPlanSimpleSTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PL_PLANSIMPLESTRAJ_I *(in_PlanSimpleSTraj_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerPlanSimpleSTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PL_PLANSIMPLESTRAJ_I *(in_PlanSimpleSTraj_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerSetManaSysRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PL_SETMANASYS_I *(in_SetManaSys_I),
					 int replyTimeOut);

extern int MPC_plannerSetManaSysReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerSetManaSysRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PL_SETMANASYS_I *(in_SetManaSys_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerSetManaSysRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PL_SETMANASYS_I *(in_SetManaSys_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerStartPathRecordingRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PATHRECORDING_I *(in_PathRecording_I),
					 int replyTimeOut);

extern int MPC_plannerStartPathRecordingReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerStartPathRecordingRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PATHRECORDING_I *(in_PathRecording_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerStartPathRecordingRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PATHRECORDING_I *(in_PathRecording_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerStopPathRecordingRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MPC_plannerStopPathRecordingReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int MPC_plannerStopPathRecordingRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS MPC_plannerLoadPathRqstSend (CLIENT_ID clientId, int *pRqstId,
					 LOADPATH_I *(in_LoadPath_I),
					 int replyTimeOut);

extern int MPC_plannerLoadPathReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerLoadPathRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					LOADPATH_I *(in_LoadPath_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerLoadPathRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					LOADPATH_I *(in_LoadPath_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerLoadPathFromLocRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FILENAME_I *(in_Path_filename_I),
					 int replyTimeOut);

extern int MPC_plannerLoadPathFromLocReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerLoadPathFromLocRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerLoadPathFromLocRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerSavePathRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FILENAME_I *(in_Path_filename_I),
					 int replyTimeOut);

extern int MPC_plannerSavePathReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerSavePathRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerSavePathRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerReinitPathRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MPC_plannerReinitPathReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int MPC_plannerReinitPathRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS MPC_plannerConcatPathRqstSend (CLIENT_ID clientId, int *pRqstId,
					 LOADPATH_I *(in_LoadPath_I),
					 int replyTimeOut);

extern int MPC_plannerConcatPathReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerConcatPathRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					LOADPATH_I *(in_LoadPath_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerConcatPathRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					LOADPATH_I *(in_LoadPath_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerStartTrajRecordingRqstSend (CLIENT_ID clientId, int *pRqstId,
					 TRAJRECORDING_I *(in_TrajRecording_I),
					 int replyTimeOut);

extern int MPC_plannerStartTrajRecordingReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerStartTrajRecordingRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					TRAJRECORDING_I *(in_TrajRecording_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerStartTrajRecordingRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					TRAJRECORDING_I *(in_TrajRecording_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerLoadTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FILENAME_I *(in_Path_filename_I),
					 int replyTimeOut);

extern int MPC_plannerLoadTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerLoadTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerLoadTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerSaveTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FILENAME_I *(in_Path_filename_I),
					 int replyTimeOut);

extern int MPC_plannerSaveTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerSaveTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerSaveTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerPlanTrajPVDRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PVD_I *(in_PlanTrajPVD_I),
					 int replyTimeOut);

extern int MPC_plannerPlanTrajPVDReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerPlanTrajPVDRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PVD_I *(in_PlanTrajPVD_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerPlanTrajPVDRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PVD_I *(in_PlanTrajPVD_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerRotateTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 float *(in_rot_angle),
					 int replyTimeOut);

extern int MPC_plannerRotateTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerRotateTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					float *(in_rot_angle), 
					
					int *activity, int *bilan);

extern int MPC_plannerRotateTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					float *(in_rot_angle), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerShiftLatTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 float *(in_shift_dist),
					 int replyTimeOut);

extern int MPC_plannerShiftLatTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerShiftLatTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					float *(in_shift_dist), 
					
					int *activity, int *bilan);

extern int MPC_plannerShiftLatTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					float *(in_shift_dist), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerShiftXYTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SHIFT_XY_I *(in_shift_xy),
					 int replyTimeOut);

extern int MPC_plannerShiftXYTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerShiftXYTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SHIFT_XY_I *(in_shift_xy), 
					
					int *activity, int *bilan);

extern int MPC_plannerShiftXYTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SHIFT_XY_I *(in_shift_xy), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerLoadRobufastPathRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FILENAME_I *(in_Path_filename_I),
					 int replyTimeOut);

extern int MPC_plannerLoadRobufastPathReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerLoadRobufastPathRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity, int *bilan);

extern int MPC_plannerLoadRobufastPathRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FILENAME_I *(in_Path_filename_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_plannerLoadRobufastPath2RqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int MPC_plannerLoadRobufastPath2ReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_plannerLoadRobufastPath2RqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int MPC_plannerLoadRobufastPath2RqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* MPC_planner_MSG_LIB_H */

